#
# spec file for package amdgpu_top
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           amdgpu_top
Version:        0.10.4
Release:        1.1
Summary:        Tool that displays AMD GPU utilization
License:        MIT
URL:            https://github.com/Umio-Yasuno/amdgpu_top
Source0:        %{name}-%{version}.tar.zst
Source1:        vendor.tar.zst
BuildRequires:  cargo-packaging >= 1.2.0
BuildRequires:  cargo >= 1.85
BuildRequires:  pkgconfig(libdrm)
BuildRequires:  pkgconfig(libdrm_amdgpu)
Requires:       libwayland-egl1
Requires:       libxkbcommon0

%description
Tool that displays AMD GPU utilization.
The tool displays information gathered from performance counters (GRBM, GRBM2), sensors, fdinfo, and AMDGPU driver.

%prep
%autosetup -a1 -p1

%build
%{cargo_build} --all

%install
install -Dm 0755 target/release/amdgpu_top %{buildroot}%{_bindir}/amdgpu_top
install -Dm 0644 docs/%{name}.1 %{buildroot}%{_mandir}/man1/%{name}.1
install -Dm 0644 assets/%{name}.desktop %{buildroot}%{_datadir}/applications/%{name}.desktop
install -Dm 0644 assets/%{name}-tui.desktop %{buildroot}%{_datadir}/applications/%{name}-tui.desktop

%files
%license LICENSE
%doc README.md docs/*.md
%{_bindir}/amdgpu_top
%{_mandir}/man1/%{name}.1%{?ext_man}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/applications/%{name}-tui.desktop

%changelog
* Mon Mar 17 2025 ecsos@opensuse.org
- Update to version 0.10.4:
  * v0.10.4
  * update dependencies
  * lib: update libdrm_amdgpu_sys rev
  * tui: update info_bar
  * lib: update libdrm_amdgpu_sys rev
  * lib: use smu_ip_version instead of asic_name
  * lib: check that fan_rpm is None
  * lib: implement workaround for RDNA 4 dGPU (SMU v14.0.2/3) dose not have fan1_input
  * lib: implement workaround for Raphael/Granite Ridge APU reported input power
  * print DevicePath in hex
* Fri Feb 14 2025 ecsos@opensuse.org
- Update to version 0.10.3:
  * v0.10.3
  * lib: fix filter_proc when short cmdline
  * update dump_xdna_device
  * lib, xdna: get_xdna_metadata
  * lib: fix Cargo.toml
* Fri Feb 14 2025 ecsos@opensuse.org
- Update to version 0.10.2:
  - reduce allocations and improve dump commands
  - support for dynamic loading of libdrm and libdrm_amdgpu (amdgpu_top remains a dynamic link)
  - specify rev of libdrm_amdgpu_sys (#109)
  - add fdinfo description in README.md (#115)
  - Add remark to build on Fedora (#117, by @jdeluyck)
  - update release.yml
  - use ubuntu-22.04 image
  - add ubuntu-22.04-arm image
  - add aarch64/arm64 binaries to the release
  - update DevicePath::check_if_device_is_active for env where CONFIG_PM is disabled (#119)
  * XDNA
  - fix the detection of XDNA NPU (#120, tested by @GreyXor)
  - impl ioctl for amdxdna-driver (tested by @GreyXor)
  * TUI
  - add "--hide-fdinfo" option for TUI mode (#108)
  - update help for toggle (#111)
  - collapsible view in one row (#112)
  - collapse panel without delay (#113)
  * GUI
  - Add Georgian tranlsation (#116, by @NorwayFun)
* Mon Jan  6 2025 Marek Sapota <marek@sapota.org>
- Add missing runtime requirements.
  * libwayland-egl1
  * libxkbcommon0
  * Fixes boo#1235098
* Sun Jan  5 2025 Marek Sapota <marek@sapota.org>
- Update to version 0.10.1
- v0.10.1
  * Update libdrm_amdgpu_sys
  * Fix CHIP_CLASS check for GFX12
  * Include CHIP_GFX1103_R1X (Hawk Point1) in has_npu condition
  * Add description of --xdna option
  * Add new layout for wide term (150 or more columns) (#107)
  * Fix "No localization for id"
  * Add CPU Core Power Plot
  * Add CPU Temperature Plot
  * Add VCLK/DCLK Plot
  * Persist selected PCI bus
- v0.10.0
  * Support for AMD XDNA NPU (amd/xdna-driver)
  * Update libdrm_amdgpu_sys
  * Support for GFX12 family (RDNA 4), CHIP_GFX1200 and CHIP_GFX1201
  * Support for CHIP_GFX1103_R1X (Hawk Point1) and CHIP_GFX1103_R2X (Hawk Point2)
  * Update GRBM2_INDEX
  * Rename "RunList Controller" to "Ring List Controller"
  * Fix the "Ring List Controller" bit for GFX10_3 (RDNA 2)
  * Stop using get_unchecked (#104)
  * Add metainfo file
  * Remove amd_.*_visible_vram fields in FdInfoUsage
  * ref: https://lists.freedesktop.org/archives/amd-gfx/2024-September/113971.html
  * Implement dynamic_no_pc
  * This allows the APU to transition to GFXOFF state.
  * Add --gl and --vk options
  * Support for the Close shortcut key (#97)
  * Add the Quit button
  * Update eframe to v0.29
  * Update versions of i18n-embed and i18n-embed-fl
  * Use LazyLock instead of once_cell
  * Use wgpu feature (#101)
  * This allows to get the driver version (Vulkan) and use APU for rendering.
  * Enable x11 feature (#102)
  * Select the GL backend as default
* Sun Sep 22 2024 jun wang <jgwang@suse.com>
- Update to version 0.9.2
  * Support for suspended devices in TUI mode and GUI mode, if
    there are no active AMDGPU devices, amdgpu_top wake up a
    suspended device.
  * Add Activity view
  * Add Activity plot
  * Fix full_fdinfo_list
  * Persist show sidepanel state
  * Persist theme
* Tue Sep  3 2024 Antonio Teixeira <antonio.teixeira@suse.com>
- Update to version 0.9.1:
  * Rework libamdgpu_top and SMI mode, JSON mode to launch from
    suspended devices without waking them up.
  * Revert "json: update OutputJson for GpuMetrics"
    for output as raw values as possible
  * Do not scroll fdinfo list if proc len is less than 8
* Wed Jul 24 2024 Antonio Teixeira <antonio.teixeira@suse.com>
- Update to version 0.9.0:
  * Too many changes to list
  * See https://github.com/Umio-Yasuno/amdgpu_top/compare/v0.2.1...v0.9.0
- Drop %%cargo_install usage
* Sun Oct 22 2023 Erefd X <zzndb001@gmail.com>
- Install docs and desktop files
* Sun Oct 22 2023 zzndb001@gmail.com
- Update to version 0.2.1:
  * v0.2.1
  * add "-V" and "--version" options
  * update mail address
  * add git commit id to title for debug
  * gui: update dependencies
  * tui: clippy
  * gui: clippy
  * update libdrm_amdgpu_sys to v0.2.1
  * gui: add Power Profiles info to Device Info panel
  * Power Profiles
  * json: update Sensors::json
  * tui, gui: support GpuMetrics::V2_4 (for VanGogh APU & Linux Kernel 6.6-rcX)
  * update to libdrm_amdgpu_sys v0.2.0
  * gui: remove duplicate PCIe Link Speed
  * docs: add sample.json
  * json: add PCIe Link to json_info
  * json: fix JsonApp::run, usage calculation requires previous results
  * lib: if MediaEngine usage in GpuActivity is `None` or `Some(0)`, use sum of fdinfo
  * update README.md
  * update help msg
  * lib, smi, tui, json: use spawn_update_index_thread
  * json: add amdgpu_top_version to output
  * lib, tui, gui, json: cleanup the code for vcn_unified
  * lib: update GpuActivity
  * lib: use ASIC_NAME for gpu_activity
  * json: full update
  * lib: update gpu_activity for GPUs not supporting `average_{gfx,umc,mm}_activity`
  * Revert "json, dump: add power_avg"
  * json: add version to JSON mode
  * json: add info to JSON mode
  * add `--apu, --select-apu` option
  * json: re-add `-s` option for JSON mode
  * json, dump: add power_avg
  * Added Solus install instructions
  * json: use map_or
  * update README.md
  * dump info in JSON format
  * update README.md
  * gui: fix typo ("mw" -> "mv")
  * add Example of using JSON mode to README.md
  * add " (debug build)" to TITLE if debug build
  * lib, smi: cleanup
  * tui: update PerfCounterView and VramUsageView for multi-layers
  * update README.md
  * update README.md for about i18n
* Fri Oct  6 2023 Antonio Teixeira <antonio.teixeira@suse.com>
- Initial release
